@@ -28,11 +28,13 @@ def extract_conv(
         assert 1>=mode_param>=0
         min_s = torch.max(S)*mode_param
         lora_rank = torch.sum(S>min_s)
-    elif mode=='percentile':
+    elif mode=='quantile' or mode=='percentile':
         assert 1>=mode_param>=0
         s_cum = torch.cumsum(S, dim=0)
         min_cum_sum = mode_param * torch.sum(S)
         lora_rank = torch.sum(s_cum<min_cum_sum)
+    else:
+        raise NotImplementedError('Extract mode should be "fixed", "threshold", "ratio" or "quantile"')
     lora_rank = max(1, lora_rank)
     lora_rank = min(out_ch, in_ch, lora_rank)
     
@@ -88,11 +90,13 @@ def extract_linear(
         assert 1>=mode_param>=0
         min_s = torch.max(S)*mode_param
         lora_rank = torch.sum(S>min_s)
-    elif mode=='percentile':
+    elif mode=='quantile' or mode=='percentile':
         assert 1>=mode_param>=0
         s_cum = torch.cumsum(S, dim=0)
         min_cum_sum = mode_param * torch.sum(S)
         lora_rank = torch.sum(s_cum<min_cum_sum)
+    else:
+        raise NotImplementedError('Extract mode should be "fixed", "threshold", "ratio" or "quantile"')
     lora_rank = max(1, lora_rank)
     lora_rank = min(out_ch, in_ch, lora_rank)
     
